@@ -2,11 +2,11 @@
 # SHELL> Rscript hwserver.r &
 # SHELL> Rscript hwclient.r
 
-library(pbdZMQ, quietly = TRUE)
+suppressMessages(library(pbdZMQ, quietly = TRUE))
 
 ### Initial.
 context <- zmq.ctx.new()
-responder <- zmq.socket(context, .pbd_env$ZMQ.ST$REP)
+responder <- zmq.socket(context, ZMQ.ST()$REP)
 zmq.bind(responder, "tcp://*:5555")
 
 ### Send and receive 5 times.
